#!/usr/bin/python

##################################         #####   ##     ##
# Crystal Monitor                #        ##       # #   # #
# Version 6.3.2                  #       ##        #  # #  #
# (c) Mihael Simonič 2006        #       ##        #   #   #
# Licence: GPL v2                #        ##   ##  #       #
##################################         #####   #       #

# USERS DON'T EDIT!

#this import statement allows access to the karamba functions
import karamba
import os.path
#from configure import ConfigCm

def readFirstLine(fn):
    """Tries to read and return the first non-empty line from file <fn>.

    If not possible, returns the None symbol."""
    
    if os.path.exists(fn):
        try:
            f = file(fn,"r")
            line=None
            while not line:
                line = f.readline().strip()
            f.close()
            return line
        except IOError, (errno, strerror):
            print "I/O error(%s): %s" % (errno,strerror)

def getDistro():
    """Tries to get information about the installed distribution.

    Reads /etc/issue as last resort. Returns the None symbol if unsuccessful."""
    
    for fn in [ "/etc/*_version",
                "/etc/*-release",
                "/etc/*-version"]:
        distro=readFirstLine(fn)
        
        if distro:
            break
    return distro

#this is called when you widget is initialized
def initWidget(widget):
    
    distro = getDistro()
    
    if not distro:
        distro = "Unknown"
        
    print "Distro is", distro

    distroText = karamba.getThemeText(widget,"distro")
    karamba.changeText(widget,distroText,distro)
    
    pass

#this is called everytime your widget is updated
#the update inverval is specified in the .theme file
def widgetUpdated(widget):
    pass

#This gets called everytime our widget is clicked.
#Notes:
#  widget = reference to our widget
#  x = x position (relative to our widget)
#  y = y position (relative to our widget)
#  botton = button clicked:
#                    1 = Left Mouse Button
#                    2 = Middle Mouse Button
#                    3 = Right Mouse Button, but this will never happen
#                        because the right mouse button brings up the
#                        Karamba menu.
#                    4,5 = Scroll wheel up and down
def widgetClicked(widget, x, y, button):
    pass

#This gets called everytime our widget is clicked.
#Notes
#  widget = reference to our widget
#  x = x position (relative to our widget)
#  y = y position (relative to our widget)
#  botton = button being held:
#                    0 = No Mouse Button
#                    1 = Left Mouse Button
#                    2 = Middle Mouse Button
#                    3 = Right Mouse Button, but this will never happen
#                        because the right mouse button brings up the
#                        Karamba menu.
def widgetMouseMoved(widget, x, y, button):
    #Warning:  Don't do anything too intensive here
    #You don't want to run some complex piece of code everytime the mouse moves
    pass


#This gets called when an item is clicked in a popup menu you have created.
#  menu = a reference to the menu
#  id = the number of the item that was clicked.
def menuItemClicked(widget, menu, id):
    pass

#This gets called when an item is clicked in the theme CONFIGURATION menu,
#not the popup menus that you create.
#  key = the reference to the configuration key that was changed
#  value = the new value (true or false) that was selected
def menuOptionChanged(widget, key, value):
    pass

#This gets called when a meter (image, text, etc) is clicked.
# NOTE you must use attachClickArea() to make a meter
# clickable.  
#  widget = reference to your theme
#  meter = the meter clicked
#  button = the button clicked (see widgetClicked for button numbers)
def meterClicked(widget, meter, button):
    pass

#This gets called when a command you have executed with executeInteractive() outputs something
#to stdout.  This way you can get the output of for example kdialog without freezing up the widget
#waiting for kdialog to end.
#  widget = reference to your theme
#  pid = process number of the program outputting (use this if you execute more than out process)
#  output = the text the program outputted to stdout
def commandOutput(widget, pid, output):
    pass

#This gets called when an item is dropped on this widget.
# NOTE you have to call acceptDrops() before your widget will accept drops.
#  widget = reference to your theme
#  dropText = the text of the dropped item (probably a URL to it's location in KDE)
def itemDropped(widget, dropText):
    pass


#This gets called when a new program is LOADING in KDE.  When it is done
#loading, startupRemoved() is called, followed by taskAdded().
#  widget = reference to your widget
#  task = A refence to the task that is starting.  
def startupAdded(widget, startup):
    pass

#This gets called when a new program is done LOADING in KDE.
#  widget = reference to your widget
#  task = A refence to the task that just finished loading.  
def startupRemoved(widget, startup):
    pass

#This is called every time a new task (program) is started in KDE.
#  widget = reference to your widget
#  task = A refence to the new task.  Call getTaskInfo() with this reference
#         to get the name, etc of this new task.
def taskAdded(widget, task):
    pass

#This is called everytime a task (program) is closed in KDE.
#  widget = reference to your widget
#  task = A refence to the task.  
def taskRemoved(widget, task):
    pass

#This is called everytime a different task gains focus (IE, the user clicks
#on a different window).  
#  widget = reference to your widget
#  task = A refence to the task.  Call getTaskInfo() with this reference
#         to get the name, etc of this new task.
def activeTaskChanged(widget, task):
    pass

# This will be printed when the widget loads.
print "Loaded Guess distro modul"
print "Loaded all CrystalMonitor python extensions!"
print "(c) 2006 Mihael Simonič <smihael@gmail.com>"
